import { useContext, useEffect } from "react";
import { FormGroupHandlerContext } from "../context/FormGroupHandler";
import Masks from "../context/Masks";
import Validations from "../context/Validations";

type FormGroupHandlerHookProps = {
  name: string;
  required?: boolean | string;
  label?: string;
  defaultValue?: any;
  validation?: string;
  mask?: string;
};

export function useFormGroupHandler({
  name,
  required,
  label,
  defaultValue,
  validation,
  mask,
}: FormGroupHandlerHookProps) {
  const formGroupHandlerContext = useContext(FormGroupHandlerContext);

  useEffect(() => {
    formGroupHandlerContext.getInitialForms({
      name,
      required,
      label,
      defaultValue,
    });
  }, [name, required, label, defaultValue, formGroupHandlerContext]);

  const data = formGroupHandlerContext.forms[name] ?? {
    value: defaultValue ?? "",
    errorMessage: null,
    required,
    label,
  };

  const setError = (errorMessage: string | null) => {
    formGroupHandlerContext.setError(name, errorMessage);
  };

  const setValue = (value: any) => {
    let newValue = value;
    newValue = checkMask(newValue);
    checkValidation(newValue);
    formGroupHandlerContext.setValue(name, newValue);
  };

  const checkMask = (value: any) => {
    if (mask) {
      const masks = Masks.instance.getMasks();
      const maskToUse = masks[mask];
      const newValue = maskToUse(value);

      return newValue;
    }
    return value;
  };

  const checkValidation = (value: any) => {
    if (validation) {
      const validations = Validations.instance.getValidations();
      const validationToTest = validations[validation];
      const { error } = validationToTest(value);
      console.log({ error });
      setError(error);
    }
  };

  return {
    ...formGroupHandlerContext,
    setError,
    setValue,
    data,
  };
}
